You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@isis.apache.org by da...@apache.org on 2012/10/08 20:44:38 UTC

svn commit: r1395713 [2/2] - in /incubator/isis/trunk/framework: core/metamodel/src/main/java/org/apache/isis/core/metamodel/facetapi/ core/metamodel/src/main/java/org/apache/isis/core/metamodel/runtimecontext/ core/metamodel/src/main/java/org/apache/i...

Modified: incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/persistence/PersistenceSessionFactoryDelegating.java
URL: http://svn.apache.org/viewvc/incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/persistence/PersistenceSessionFactoryDelegating.java?rev=1395713&r1=1395712&r2=1395713&view=diff
==============================================================================
--- incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/persistence/PersistenceSessionFactoryDelegating.java (original)
+++ incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/persistence/PersistenceSessionFactoryDelegating.java Mon Oct  8 18:44:36 2012
@@ -19,17 +19,32 @@
 
 package org.apache.isis.runtimes.dflt.runtime.persistence;
 
+import static org.apache.isis.core.commons.ensure.Ensure.ensureThatArg;
 import static org.apache.isis.core.commons.ensure.Ensure.ensureThatState;
 import static org.hamcrest.CoreMatchers.is;
+import static org.hamcrest.CoreMatchers.not;
 import static org.hamcrest.CoreMatchers.notNullValue;
+import static org.hamcrest.CoreMatchers.nullValue;
 
 import java.util.List;
 
+import org.apache.isis.applib.DomainObjectContainer;
 import org.apache.isis.applib.clock.Clock;
 import org.apache.isis.applib.fixtures.FixtureClock;
+import org.apache.isis.core.commons.config.IsisConfiguration;
+import org.apache.isis.core.metamodel.adapter.ObjectAdapterFactory;
+import org.apache.isis.core.metamodel.progmodel.ProgrammingModel;
+import org.apache.isis.core.metamodel.runtimecontext.RuntimeContext;
+import org.apache.isis.core.metamodel.services.ServicesInjectorSpi;
 import org.apache.isis.core.metamodel.spec.SpecificationLoaderSpi;
+import org.apache.isis.core.metamodel.specloader.classsubstitutor.ClassSubstitutor;
+import org.apache.isis.core.metamodel.specloader.validator.MetaModelValidator;
+import org.apache.isis.core.metamodel.specloader.validator.MetaModelValidatorComposite;
+import org.apache.isis.runtimes.dflt.runtime.persistence.adaptermanager.PojoRecreator;
 import org.apache.isis.runtimes.dflt.runtime.system.DeploymentType;
 import org.apache.isis.runtimes.dflt.runtime.system.context.IsisContext;
+import org.apache.isis.runtimes.dflt.runtime.system.persistence.IdentifierGenerator;
+import org.apache.isis.runtimes.dflt.runtime.system.persistence.ObjectFactory;
 import org.apache.isis.runtimes.dflt.runtime.system.persistence.PersistenceSession;
 import org.apache.isis.runtimes.dflt.runtime.system.persistence.PersistenceSessionFactory;
 
@@ -40,13 +55,24 @@ import org.apache.isis.runtimes.dflt.run
 public class PersistenceSessionFactoryDelegating implements PersistenceSessionFactory, FixturesInstalledFlag {
 
     private final DeploymentType deploymentType;
+    private final IsisConfiguration configuration;
     private final PersistenceSessionFactoryDelegate persistenceSessionFactoryDelegate;
+    
     private List<Object> serviceList;
 
     private Boolean fixturesInstalled;
+    
+    private PojoRecreator pojoRecreator;
+    private ObjectAdapterFactory adapterFactory;
+    private ObjectFactory objectFactory;
+    private IdentifierGenerator identifierGenerator;
+    private ServicesInjectorSpi servicesInjector;
+    private DomainObjectContainer container;
+    private RuntimeContext runtimeContext;
 
-    public PersistenceSessionFactoryDelegating(final DeploymentType deploymentType, final PersistenceSessionFactoryDelegate persistenceSessionFactoryDelegate) {
+    public PersistenceSessionFactoryDelegating(final DeploymentType deploymentType, final IsisConfiguration isisConfiguration, final PersistenceSessionFactoryDelegate persistenceSessionFactoryDelegate) {
         this.deploymentType = deploymentType;
+        this.configuration = isisConfiguration;
         this.persistenceSessionFactoryDelegate = persistenceSessionFactoryDelegate;
     }
 
@@ -81,19 +107,44 @@ public class PersistenceSessionFactoryDe
             FixtureClock.initialize();
         }
 
-        doInit();
-    }
+        pojoRecreator = persistenceSessionFactoryDelegate.createPojoRecreator(getConfiguration());
+        adapterFactory = persistenceSessionFactoryDelegate.createAdapterFactory(getConfiguration());
+        objectFactory = persistenceSessionFactoryDelegate.createObjectFactory(getConfiguration());
+        identifierGenerator = persistenceSessionFactoryDelegate.createIdentifierGenerator(getConfiguration());
+
+        ensureThatState(pojoRecreator, is(not(nullValue())));
+        ensureThatState(adapterFactory, is(not(nullValue())));
+        ensureThatState(objectFactory, is(not(nullValue())));
+        ensureThatState(identifierGenerator, is(not(nullValue())));
+
+        servicesInjector = persistenceSessionFactoryDelegate.createServicesInjector(getConfiguration());
+        container = persistenceSessionFactoryDelegate.createContainer(getConfiguration());
+
+        ensureThatState(servicesInjector, is(not(nullValue())));
+        ensureThatState(container, is(not(nullValue())));
+
+        runtimeContext = persistenceSessionFactoryDelegate.createRuntimeContext(getConfiguration());
+        ensureThatState(runtimeContext, is(not(nullValue())));
+
+        
+        // wire up components
+
+        getSpecificationLoader().injectInto(runtimeContext);
+        runtimeContext.injectInto(container);
+        runtimeContext.setContainer(container);
+        for (Object service : serviceList) {
+            runtimeContext.injectInto(service);
+        }
 
-    /**
-     * Optional hook method for implementation-specific initialization.
-     */
-    protected void doInit() {
+        servicesInjector.setContainer(container);
+        servicesInjector.setServices(serviceList);
+        servicesInjector.init();
     }
 
+
     @Override
     public final void shutdown() {
         doShutdown();
-        // other
     }
 
     /**
@@ -102,6 +153,63 @@ public class PersistenceSessionFactoryDe
     protected void doShutdown() {
     }
 
+    
+    // //////////////////////////////////////////////////////
+    // Components (setup during init...)
+    // //////////////////////////////////////////////////////
+
+    public ObjectAdapterFactory getAdapterFactory() {
+        return adapterFactory;
+    }
+    
+    public IdentifierGenerator getIdentifierGenerator() {
+        return identifierGenerator;
+    }
+    
+    public ObjectFactory getObjectFactory() {
+        return objectFactory;
+    }
+    
+    public PojoRecreator getPojoRecreator() {
+        return pojoRecreator;
+    }
+
+    public RuntimeContext getRuntimeContext() {
+        return runtimeContext;
+    }
+    
+    public ServicesInjectorSpi getServicesInjector() {
+        return servicesInjector;
+    }
+    
+    public List<Object> getServiceList() {
+        return serviceList;
+    }
+
+    public DomainObjectContainer getContainer() {
+        return container;
+    }
+
+    // //////////////////////////////////////////////////////
+    // MetaModelAdjuster impl
+    // //////////////////////////////////////////////////////
+
+    @Override
+    public ClassSubstitutor createClassSubstitutor(final IsisConfiguration configuration) {
+        return persistenceSessionFactoryDelegate.createClassSubstitutor(configuration);
+    }
+
+    @Override
+    public MetaModelValidator refineMetaModelValidator(MetaModelValidatorComposite metaModelValidator, IsisConfiguration configuration) {
+        return persistenceSessionFactoryDelegate.refineMetaModelValidator(metaModelValidator, configuration);
+    }
+
+    @Override
+    public ProgrammingModel refineProgrammingModel(ProgrammingModel baseProgrammingModel, IsisConfiguration configuration) {
+        return persistenceSessionFactoryDelegate.refineProgrammingModel(baseProgrammingModel, configuration);
+    }
+
+
     // //////////////////////////////////////////////////////
     // FixturesInstalledFlag impl
     // //////////////////////////////////////////////////////
@@ -117,6 +225,14 @@ public class PersistenceSessionFactoryDe
     }
 
     // //////////////////////////////////////////////////////
+    // Dependencies (injected from constructor)
+    // //////////////////////////////////////////////////////
+
+    public IsisConfiguration getConfiguration() {
+        return configuration;
+    }
+    
+    // //////////////////////////////////////////////////////
     // Dependencies (injected via setters)
     // //////////////////////////////////////////////////////
 
@@ -131,12 +247,15 @@ public class PersistenceSessionFactoryDe
     }
 
 
-    
     // //////////////////////////////////////////////////////
     // Dependencies (from context)
     // //////////////////////////////////////////////////////
 
+    
     protected SpecificationLoaderSpi getSpecificationLoader() {
         return IsisContext.getSpecificationLoader();
     }
+
+
+
 }

Modified: incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/system/IsisSystemFixturesHookAbstract.java
URL: http://svn.apache.org/viewvc/incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/system/IsisSystemFixturesHookAbstract.java?rev=1395713&r1=1395712&r2=1395713&view=diff
==============================================================================
--- incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/system/IsisSystemFixturesHookAbstract.java (original)
+++ incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/system/IsisSystemFixturesHookAbstract.java Mon Oct  8 18:44:36 2012
@@ -29,6 +29,7 @@ import org.apache.isis.core.commons.conf
 import org.apache.isis.core.commons.debug.DebugBuilder;
 import org.apache.isis.core.commons.debug.DebuggableWithTitle;
 import org.apache.isis.core.metamodel.adapter.oid.OidMarshaller;
+import org.apache.isis.core.metamodel.facetapi.MetaModelRefiner;
 import org.apache.isis.core.metamodel.spec.SpecificationLoaderSpi;
 import org.apache.isis.core.runtime.about.AboutIsis;
 import org.apache.isis.core.runtime.authentication.AuthenticationManager;
@@ -209,7 +210,7 @@ public abstract class IsisSystemFixtures
     // Reflector
     // ///////////////////////////////////////////
 
-    protected abstract SpecificationLoaderSpi obtainSpecificationLoaderSpi(DeploymentType deploymentType) throws IsisSystemException;
+    protected abstract SpecificationLoaderSpi obtainSpecificationLoaderSpi(DeploymentType deploymentType, MetaModelRefiner facetFactoriesProvider) throws IsisSystemException;
 
     // ///////////////////////////////////////////
     // PersistenceSessionFactory

Modified: incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/system/persistence/PersistenceSession.java
URL: http://svn.apache.org/viewvc/incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/system/persistence/PersistenceSession.java?rev=1395713&r1=1395712&r2=1395713&view=diff
==============================================================================
--- incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/system/persistence/PersistenceSession.java (original)
+++ incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/system/persistence/PersistenceSession.java Mon Oct  8 18:44:36 2012
@@ -227,7 +227,6 @@ public class PersistenceSession implemen
         // wire dependencies into adapterManager
         servicesInjector.injectInto(adapterManager);
 
-        servicesInjector.open();
         objectFactory.open();
         adapterManager.open();
 
@@ -267,7 +266,6 @@ public class PersistenceSession implemen
         objectStore.close();
 
         adapterManager.close();
-        servicesInjector.close();
         objectFactory.close();
 
         setState(State.CLOSED);

Modified: incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/system/persistence/PersistenceSessionFactory.java
URL: http://svn.apache.org/viewvc/incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/system/persistence/PersistenceSessionFactory.java?rev=1395713&r1=1395712&r2=1395713&view=diff
==============================================================================
--- incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/system/persistence/PersistenceSessionFactory.java (original)
+++ incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/system/persistence/PersistenceSessionFactory.java Mon Oct  8 18:44:36 2012
@@ -22,16 +22,36 @@ package org.apache.isis.runtimes.dflt.ru
 import java.util.List;
 
 import org.apache.isis.core.commons.components.ApplicationScopedComponent;
+import org.apache.isis.core.metamodel.adapter.ObjectAdapterFactory;
+import org.apache.isis.core.metamodel.facetapi.MetaModelRefiner;
+import org.apache.isis.core.metamodel.services.ServicesInjectorSpi;
 import org.apache.isis.runtimes.dflt.runtime.persistence.PersistenceSessionFactoryDelegate;
+import org.apache.isis.runtimes.dflt.runtime.persistence.adaptermanager.PojoRecreator;
 import org.apache.isis.runtimes.dflt.runtime.system.DeploymentType;
 
 /**
  * @see PersistenceSessionFactoryDelegate
  */
-public interface PersistenceSessionFactory extends ApplicationScopedComponent {
+public interface PersistenceSessionFactory extends MetaModelRefiner, ApplicationScopedComponent {
 
     DeploymentType getDeploymentType();
 
+
+    // //////////////////////////////////////////////////////
+    // Singleton threadsafe components
+    // //////////////////////////////////////////////////////
+
+    ObjectAdapterFactory getAdapterFactory();
+    ObjectFactory getObjectFactory();
+    PojoRecreator getPojoRecreator();
+    IdentifierGenerator getIdentifierGenerator();
+    ServicesInjectorSpi getServicesInjector();
+
+    
+    // //////////////////////////////////////////////////////
+    // main API
+    // //////////////////////////////////////////////////////
+
     /**
      * Creates a {@link PersistenceSession} with the implementing object as the
      * {@link PersistenceSession}'s
@@ -47,4 +67,8 @@ public interface PersistenceSessionFacto
 
     public List<Object> getServices();
 
+
+
+
+
 }

Modified: incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/systemusinginstallers/IsisSystemAbstract.java
URL: http://svn.apache.org/viewvc/incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/systemusinginstallers/IsisSystemAbstract.java?rev=1395713&r1=1395712&r2=1395713&view=diff
==============================================================================
--- incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/systemusinginstallers/IsisSystemAbstract.java (original)
+++ incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/systemusinginstallers/IsisSystemAbstract.java Mon Oct  8 18:44:36 2012
@@ -175,7 +175,7 @@ public abstract class IsisSystemAbstract
         final AuthenticationManager authenticationManager = obtainAuthenticationManager(deploymentType);
         final AuthorizationManager authorizationManager = obtainAuthorizationManager(deploymentType);
         final TemplateImageLoader templateImageLoader = obtainTemplateImageLoader();
-        final SpecificationLoaderSpi reflector = obtainSpecificationLoaderSpi(deploymentType);
+        final SpecificationLoaderSpi reflector = obtainSpecificationLoaderSpi(deploymentType, persistenceSessionFactory);
         final OidMarshaller oidMarshaller = obtainOidMarshaller();
 
         final List<Object> servicesList = obtainServices();

Modified: incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/systemusinginstallers/IsisSystemUsingInstallers.java
URL: http://svn.apache.org/viewvc/incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/systemusinginstallers/IsisSystemUsingInstallers.java?rev=1395713&r1=1395712&r2=1395713&view=diff
==============================================================================
--- incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/systemusinginstallers/IsisSystemUsingInstallers.java (original)
+++ incubator/isis/trunk/framework/runtimes/dflt/runtime/src/main/java/org/apache/isis/runtimes/dflt/runtime/systemusinginstallers/IsisSystemUsingInstallers.java Mon Oct  8 18:44:36 2012
@@ -30,6 +30,7 @@ import java.util.List;
 import org.apache.log4j.Logger;
 
 import org.apache.isis.core.commons.config.IsisConfiguration;
+import org.apache.isis.core.metamodel.facetapi.MetaModelRefiner;
 import org.apache.isis.core.metamodel.spec.SpecificationLoaderSpi;
 import org.apache.isis.core.metamodel.specloader.ObjectReflectorInstaller;
 import org.apache.isis.core.runtime.authentication.AuthenticationManager;
@@ -200,7 +201,7 @@ public class IsisSystemUsingInstallers e
     }
 
     @Override
-    protected SpecificationLoaderSpi obtainSpecificationLoaderSpi(final DeploymentType deploymentType) throws IsisSystemException {
+    protected SpecificationLoaderSpi obtainSpecificationLoaderSpi(final DeploymentType deploymentType, final MetaModelRefiner programmingModelAdjuster) throws IsisSystemException {
         if (reflectorInstaller == null) {
             final String fromCmdLine = getConfiguration().getString(SystemConstants.REFLECTOR_KEY);
             reflectorInstaller = installerLookup.reflectorInstaller(fromCmdLine);
@@ -210,7 +211,8 @@ public class IsisSystemUsingInstallers e
         // add in transaction support (if already in set then will be ignored)
         reflectorInstaller.addFacetDecoratorInstaller(installerLookup.getInstaller(TransactionFacetDecoratorInstaller.class));
 
-        return reflectorInstaller.createReflector();
+        final SpecificationLoaderSpi reflector = reflectorInstaller.createReflector(programmingModelAdjuster);
+        return reflector;
     }
 
     // ///////////////////////////////////////////

Modified: incubator/isis/trunk/framework/runtimes/dflt/testsupport/src/main/java/org/apache/isis/runtimes/dflt/testsupport/IsisSystemDefault.java
URL: http://svn.apache.org/viewvc/incubator/isis/trunk/framework/runtimes/dflt/testsupport/src/main/java/org/apache/isis/runtimes/dflt/testsupport/IsisSystemDefault.java?rev=1395713&r1=1395712&r2=1395713&view=diff
==============================================================================
--- incubator/isis/trunk/framework/runtimes/dflt/testsupport/src/test/java/org/apache/isis/runtimes/dflt/runtime/persistence/PersistorSessionHydratorTest.java (original)
+++ incubator/isis/trunk/framework/runtimes/dflt/testsupport/src/test/java/org/apache/isis/runtimes/dflt/runtime/persistence/PersistorSessionHydratorTest.java Mon Oct  8 18:44:36 2012
@@ -72,7 +72,7 @@ public class PersistorSessionHydratorTes
     public IsisSystemWithFixtures iswf = IsisSystemWithFixtures.builder()
         .with(Initialization.NO_INIT)
         .with(new InMemoryPersistenceMechanismInstaller() {
-            protected IdentifierGenerator createIdentifierGenerator(IsisConfiguration configuration) {
+            public IdentifierGenerator createIdentifierGenerator(IsisConfiguration configuration) {
                 return mockIdentifierGenerator;
             };
         })

Modified: incubator/isis/trunk/framework/viewer/bdd/common/src/main/java/org/apache/isis/viewer/bdd/common/components/BddInMemoryPersistenceMechanismInstaller.java
URL: http://svn.apache.org/viewvc/incubator/isis/trunk/framework/viewer/bdd/common/src/main/java/org/apache/isis/viewer/bdd/common/components/BddInMemoryPersistenceMechanismInstaller.java?rev=1395713&r1=1395712&r2=1395713&view=diff
==============================================================================
--- incubator/isis/trunk/framework/viewer/bdd/common/src/main/java/org/apache/isis/viewer/bdd/common/components/BddInMemoryPersistenceMechanismInstaller.java (original)
+++ incubator/isis/trunk/framework/viewer/bdd/common/src/main/java/org/apache/isis/viewer/bdd/common/components/BddInMemoryPersistenceMechanismInstaller.java Mon Oct  8 18:44:36 2012
@@ -42,7 +42,7 @@ public class BddInMemoryPersistenceMecha
 
     @Override
     public PersistenceSessionFactory createPersistenceSessionFactory(final DeploymentType deploymentType) {
-        return new BddInMemoryPersistenceSessionFactory(deploymentType, this);
+        return new BddInMemoryPersistenceSessionFactory(deploymentType, getConfiguration(), this);
     }
 
 }

Modified: incubator/isis/trunk/framework/viewer/bdd/common/src/main/java/org/apache/isis/viewer/bdd/common/components/BddInMemoryPersistenceSessionFactory.java
URL: http://svn.apache.org/viewvc/incubator/isis/trunk/framework/viewer/bdd/common/src/main/java/org/apache/isis/viewer/bdd/common/components/BddInMemoryPersistenceSessionFactory.java?rev=1395713&r1=1395712&r2=1395713&view=diff
==============================================================================
--- incubator/isis/trunk/framework/viewer/bdd/common/src/main/java/org/apache/isis/viewer/bdd/common/components/BddInMemoryPersistenceSessionFactory.java (original)
+++ incubator/isis/trunk/framework/viewer/bdd/common/src/main/java/org/apache/isis/viewer/bdd/common/components/BddInMemoryPersistenceSessionFactory.java Mon Oct  8 18:44:36 2012
@@ -18,6 +18,7 @@
  */
 package org.apache.isis.viewer.bdd.common.components;
 
+import org.apache.isis.core.commons.config.IsisConfiguration;
 import org.apache.isis.core.metamodel.facets.object.cached.CachedFacet;
 import org.apache.isis.core.metamodel.spec.ObjectSpecification;
 import org.apache.isis.runtimes.dflt.objectstores.dflt.InMemoryPersistenceSessionFactory;
@@ -34,8 +35,8 @@ import org.apache.isis.runtimes.dflt.run
  */
 public class BddInMemoryPersistenceSessionFactory extends InMemoryPersistenceSessionFactory {
 
-    public BddInMemoryPersistenceSessionFactory(final DeploymentType deploymentType, final PersistenceSessionFactoryDelegate persistenceSessionFactoryDelegate) {
-        super(deploymentType, persistenceSessionFactoryDelegate);
+    public BddInMemoryPersistenceSessionFactory(final DeploymentType deploymentType, final IsisConfiguration configuration, final PersistenceSessionFactoryDelegate persistenceSessionFactoryDelegate) {
+        super(deploymentType, configuration, persistenceSessionFactoryDelegate);
     }
 
     @Override

Modified: incubator/isis/trunk/framework/viewer/junit/src/main/java/org/apache/isis/viewer/junit/internal/InMemoryPersistenceMechanismInstallerWithinJunit.java
URL: http://svn.apache.org/viewvc/incubator/isis/trunk/framework/viewer/junit/src/main/java/org/apache/isis/viewer/junit/internal/InMemoryPersistenceMechanismInstallerWithinJunit.java?rev=1395713&r1=1395712&r2=1395713&view=diff
==============================================================================
--- incubator/isis/trunk/framework/viewer/junit/src/main/java/org/apache/isis/viewer/junit/internal/InMemoryPersistenceMechanismInstallerWithinJunit.java (original)
+++ incubator/isis/trunk/framework/viewer/junit/src/main/java/org/apache/isis/viewer/junit/internal/InMemoryPersistenceMechanismInstallerWithinJunit.java Mon Oct  8 18:44:36 2012
@@ -30,7 +30,7 @@ public class InMemoryPersistenceMechanis
      * Returns a {@link DomainObjectContainerHeadlessViewer}.
      */
     @Override
-    protected DomainObjectContainer createContainer(final IsisConfiguration configuration) {
+    public DomainObjectContainer createContainer(final IsisConfiguration configuration) {
         return new DomainObjectContainerWrapperFactory();
     }
 

Modified: incubator/isis/trunk/framework/viewer/wicket/wicket-model/src/main/java/org/apache/isis/viewer/wicket/model/models/ScalarModel.java
URL: http://svn.apache.org/viewvc/incubator/isis/trunk/framework/viewer/wicket/wicket-model/src/main/java/org/apache/isis/viewer/wicket/model/models/ScalarModel.java?rev=1395713&r1=1395712&r2=1395713&view=diff
==============================================================================
--- incubator/isis/trunk/framework/viewer/wicket/wicket-model/src/main/java/org/apache/isis/viewer/wicket/model/models/ScalarModel.java (original)
+++ incubator/isis/trunk/framework/viewer/wicket/wicket-model/src/main/java/org/apache/isis/viewer/wicket/model/models/ScalarModel.java Mon Oct  8 18:44:36 2012
@@ -35,7 +35,7 @@ import org.apache.isis.core.metamodel.ad
 import org.apache.isis.core.metamodel.consent.Consent;
 import org.apache.isis.core.metamodel.facetapi.Facet;
 import org.apache.isis.core.metamodel.facetapi.FacetHolder;
-import org.apache.isis.core.metamodel.facetapi.FacetProvider;
+import org.apache.isis.core.metamodel.facetapi.MetaModelRefiner;
 import org.apache.isis.core.metamodel.facets.mandatory.MandatoryFacet;
 import org.apache.isis.core.metamodel.facets.object.parseable.ParseableFacet;
 import org.apache.isis.core.metamodel.spec.ObjectSpecId;
@@ -57,7 +57,7 @@ import org.apache.isis.viewer.wicket.mod
  * Is the backing model to each of the fields that appear in forms (for entities
  * or action dialogs).
  */
-public class ScalarModel extends EntityModel implements FacetProvider {
+public class ScalarModel extends EntityModel {
 
     private static final long serialVersionUID = 1L;
--- incubator/isis/trunk/framework/runtimes/dflt/testsupport/src/main/java/org/apache/isis/runtimes/dflt/testsupport/IsisSystemDefault.java (original)
+++ incubator/isis/trunk/framework/runtimes/dflt/testsupport/src/main/java/org/apache/isis/runtimes/dflt/testsupport/IsisSystemDefault.java Mon Oct  8 18:44:36 2012
@@ -11,6 +11,7 @@ import com.google.common.collect.Sets;
 import org.apache.isis.core.commons.config.IsisConfiguration;
 import org.apache.isis.core.commons.config.IsisConfigurationDefault;
 import org.apache.isis.core.commons.resource.ResourceStreamSourceContextLoaderClassPath;
+import org.apache.isis.core.metamodel.facetapi.MetaModelRefiner;
 import org.apache.isis.core.metamodel.facetdecorator.FacetDecorator;
 import org.apache.isis.core.metamodel.layout.MemberLayoutArranger;
 import org.apache.isis.core.metamodel.progmodel.ProgrammingModel;
@@ -119,7 +120,7 @@ public class IsisSystemDefault extends I
      * @see #obtainReflectorSpecificationTraverser()
      */
     @Override
-    protected SpecificationLoaderSpi obtainSpecificationLoaderSpi(DeploymentType deploymentType) throws IsisSystemException {
+    protected SpecificationLoaderSpi obtainSpecificationLoaderSpi(DeploymentType deploymentType, MetaModelRefiner facetFactoriesProvider) throws IsisSystemException {
         ClassSubstitutor classSubstitutor = obtainReflectorClassSubstitutor();
         CollectionTypeRegistry collectionTypeRegistry = obtainReflectorCollectionTypeRegistry();
         SpecificationTraverser specificationTraverser = obtainReflectorSpecificationTraverser();
@@ -131,7 +132,7 @@ public class IsisSystemDefault extends I
     }
 
     /**
      * Optional hook method, called from {@link #obtainSpecificationLoaderSpi(DeploymentType)}.
      * @return
      */
     protected ClassSubstitutor obtainReflectorClassSubstitutor() {
@@ -139,7 +140,7 @@ public class IsisSystemDefault extends I
     }
 
     /**
      * Optional hook method, called from {@link #obtainSpecificationLoaderSpi(DeploymentType)}.
      * @return
      */
     protected CollectionTypeRegistry obtainReflectorCollectionTypeRegistry() {
@@ -147,7 +148,7 @@ public class IsisSystemDefault extends I
     }
 
     /**
      * Optional hook method, called from {@link #obtainSpecificationLoaderSpi(DeploymentType)}.
      * @return
      */
     protected SpecificationTraverser obtainReflectorSpecificationTraverser() {
@@ -155,7 +156,7 @@ public class IsisSystemDefault extends I
     }
 
     /**
      * Optional hook method, called from {@link #obtainSpecificationLoaderSpi(DeploymentType)}.
      * @return
      */
     protected ProgrammingModel obtainReflectorProgrammingModel() {
@@ -163,7 +164,7 @@ public class IsisSystemDefault extends I
     }
 
     /**
      * Optional hook method, called from {@link #obtainSpecificationLoaderSpi(DeploymentType)}.
      * @return
      */
     protected Set<FacetDecorator> obtainReflectorFacetDecoratorSet() {
@@ -171,7 +172,7 @@ public class IsisSystemDefault extends I
     }
 
     /**
      * Optional hook method, called from {@link #obtainSpecificationLoaderSpi(DeploymentType)}.
      * @return
      */
     protected MetaModelValidator obtainReflectorMetaModelValidator() {
@@ -131,7 +132,7 @@ public class IsisSystemDefault extends I
 
     /**
-     * Optional hook method, called from {@link #obtainSpecificationLoaderSpi(DeploymentType)}.
+     * Optional hook method, called from {@link #obtainSpecificationLoaderSpi(DeploymentType, MetaModelRefiner)}.
      * @return
      */
@@ -139,7 +140,7 @@ public class IsisSystemDefault extends I
 
     /**
-     * Optional hook method, called from {@link #obtainSpecificationLoaderSpi(DeploymentType)}.
+     * Optional hook method, called from {@link #obtainSpecificationLoaderSpi(DeploymentType, MetaModelRefiner)}.
      * @return
      */
@@ -147,7 +148,7 @@ public class IsisSystemDefault extends I
 
     /**
-     * Optional hook method, called from {@link #obtainSpecificationLoaderSpi(DeploymentType)}.
+     * Optional hook method, called from {@link #obtainSpecificationLoaderSpi(DeploymentType, MetaModelRefiner)}.
      * @return
      */
@@ -155,7 +156,7 @@ public class IsisSystemDefault extends I
 
     /**
-     * Optional hook method, called from {@link #obtainSpecificationLoaderSpi(DeploymentType)}.
+     * Optional hook method, called from {@link #obtainSpecificationLoaderSpi(DeploymentType, MetaModelRefiner)}.
      * @return
      */
@@ -163,7 +164,7 @@ public class IsisSystemDefault extends I
 
     /**
-     * Optional hook method, called from {@link #obtainSpecificationLoaderSpi(DeploymentType)}.
+     * Optional hook method, called from {@link #obtainSpecificationLoaderSpi(DeploymentType, MetaModelRefiner)}.
      * @return
      */
@@ -171,7 +172,7 @@ public class IsisSystemDefault extends I
 
     /**
-     * Optional hook method, called from {@link #obtainSpecificationLoaderSpi(DeploymentType)}.
+     * Optional hook method, called from {@link #obtainSpecificationLoaderSpi(DeploymentType, MetaModelRefiner)}.
      * @return
      */

Modified: incubator/isis/trunk/framework/runtimes/dflt/testsupport/src/test/java/org/apache/isis/runtimes/dflt/runtime/persistence/PersistorSessionHydratorTest.java
URL: http://svn.apache.org/viewvc/incubator/isis/trunk/framework/runtimes/dflt/testsupport/src/test/java/org/apache/isis/runtimes/dflt/runtime/persistence/PersistorSessionHydratorTest.java?rev=1395713&r1=1395712&r2=1395713&view=diff
==============================================================================